Documentation
¶
Overview ¶
Package apis is the main package for provider specific APIs
Package apis is the main package for provider specific APIs
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRegionFromZone ¶
GetRegionFromZone returns the region for a given zone string
PARAMETERS zone string Datacenter zone
Types ¶
type NetworkIDs ¶ added in v0.1.1
type NetworkIDs struct {
// WAN is the network ID for the public facing network interface.
WAN string `json:"wan"`
// Workers is the network ID of a worker subnet.
Workers string `json:"workers,omitempty"`
}
Networks holds information about the Kubernetes and infrastructure networks.
type ProviderSpec ¶
type ProviderSpec struct {
DatacenterID string `json:"datacenterID,omitempty"`
Cluster string `json:"cluster"`
Zone string `json:"zone"`
Cores uint `json:"cores"`
Memory uint `json:"memory"`
ImageID string `json:"imageID"`
SSHKey string `json:"sshKey"`
FloatingPoolID string `json:"floatingPoolID,omitempty"`
NetworkIDs *NetworkIDs `json:"networkIDs,omitempty"`
// Default: If you're creating the volume from a snapshot and don't specify
// a volume size, the default is the snapshot size.
VolumeSize float32 `json:"volumeSize,omitempty"`
}
ProviderSpec is the spec to be used while parsing the calls.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package mock provides all methods required to simulate a driver
|
Package mock provides all methods required to simulate a driver |
|
Package transcoder is used for API related object transformations
|
Package transcoder is used for API related object transformations |
|
Package validation - validation is used to validate cloud specific ProviderSpec
|
Package validation - validation is used to validate cloud specific ProviderSpec |
Click to show internal directories.
Click to hide internal directories.